@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Contacts" : "Контакти",
     "Download" : "Изтегляне",
+    "Copy link" : "Копирай връзката",
+    "Toggle sharing" : "Превключване на споделянето",
     "Delete" : "Изтриване",
     "Rename" : "Преименуване",
     "Share with users or groups" : "Споделяне с потребители или групи",
@@ -27,7 +29,10 @@ OC.L10N.register(
     "Save changes" : "Запис на промените",
     "Address book" : "Адресна книга",
     "Loading contacts …" : "Зареждане на контактите ...",
+    "Import into" : "Вмъкни в",
     "Importing..." : "Внасяне ...",
+    "Select your addressbook" : "Избери своята адресна книга",
+    "Import is disabled because no writable address book had been found." : "Вмъкването е изключено, защото няма налична адресна книга позволяваща записване.",
     "No search result for {query}" : "Няма намерени резултати за {query}",
     "All contacts" : "Всички контакти",
     "Post office box" : "Пощенска кутия",
@@ -42,12 +47,22 @@ OC.L10N.register(
     "Additional names" : "Други имена",
     "Prefix" : "Представка",
     "Suffix" : "Наставка",
+    "Importing into" : "Вмъкни в",
     "New contact" : "Нов контакт",
     "Not grouped" : "Негрупирани",
     "Sort by" : "Сортиране по",
+    "There is no address book available to create a contact." : "Няма налична адресна книга, където да се създаде контакта.",
     "{addressbook} shared by {owner}" : "{addressbook} споделена с {owner}",
+    "Contact not found." : "Няма намерен контакт.",
+    "You don't have permission to write to this addressbook." : "Нямате права да пишете в тази адресна книга.",
     "Contact could not be created." : "Контакта не може да бъде създаден.",
+    "No contacts in file. Only vCard files are allowed." : "Няма контакти във файла. Разрешени са само VCard файлове.",
+    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Единствено VCard версия 4.0 (RFC6350) или версия 3.0 (RFC2426) се поддържат.",
+    "Contact could not be moved." : "Контакта не може да бъде преместен.",
+    "Contact could not be saved." : "Контакта не може да бъде записан.",
+    "Waiting for the server to be ready…" : "Изчакване от сървъра на потвърждение за готовност...",
     "Importing…" : "Внасяне...",
+    "Display name" : "Име за визуализация",
     "Nickname" : "Псевдоним",
     "Detailed name" : "Детайлно име",
     "Notes" : "Бележки",
@@ -73,6 +88,7 @@ OC.L10N.register(
     "Car" : "Кола",
     "Work pager" : "Работен пейджър",
     "Social network" : "Социална мрежа",
+    "Relationship" : "Връзка",
     "Spouse" : "Съпруг",
     "Child" : "Дете",
     "Mother" : "Майка",
