@@ -34,6 +34,7 @@ OC.L10N.register(
     "Import into" : "Importovat do",
     "Importing..." : "Importování…",
     "Select your addressbook" : "Vyberte adresář",
+    "Import is disabled because no writable address book had been found." : "Import je zakázán, protože nebyl nalezen žádný zapisovatelný adresář.",
     "No search result for {query}" : "Žádný nález pro {query}",
     "All contacts" : "Všechny kontakty",
     "Post office box" : "Poštovní schránka",
@@ -52,6 +53,7 @@ OC.L10N.register(
     "New contact" : "Nový kontakt",
     "Not grouped" : "Neseskupené",
     "Sort by" : "Seřadit podle",
+    "There is no address book available to create a contact." : "K vytvoření kontaktu není dostupný žádný adresář.",
     "{addressbook} shared by {owner}" : "{addressbook} sdílí {owner}",
     "Contact not found." : "Kontakt nenalezen",
     "You don't have permission to write to this addressbook." : "Nemáte oprávnění k zápisu do tohoto adresáře.",
@@ -89,6 +91,7 @@ OC.L10N.register(
     "Work pager" : "Pracovní pager",
     "Social network" : "Sociální síť",
     "Relationship" : "Vztah",
+    "Specify a relationship between you and the entity represented by this vCard." : "Určete váš vztah k tomuto kontaktu.",
     "Spouse" : "Manželka",
     "Child" : "Dítě",
     "Mother" : "Matka",
@@ -102,13 +105,16 @@ OC.L10N.register(
     "Manager" : "Nadřízený",
     "Assistant" : "Asistent",
     "Related" : "Související",
+    "Specify a relationship between another entity and the entity represented by this vCard." : "Určete vztah mezi jinou entitou a tímto kontaktem.",
     "Contact" : "Kontakt",
+    "Agent" : "Agent",
     "Emergency" : "Nouze",
     "Co-worker" : "Spolupracovník",
     "Gender" : "Pohlaví",
     "Female" : "Žena",
     "Male" : "Muž",
     "Details" : "Detaily",
+    "A contacts app for Nextcloud" : "Aplikace správy kontaktů pro Nextcloud",
     "Settings" : "Nastavení"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
