@@ -20,6 +20,7 @@ OC.L10N.register(
     "Address book name" : "Címjegyzék neve",
     "Only these special characters are allowed: -_.!?#|()" : "Csak ezek a speciális karakterek használhatók: -_.!?#|()",
     "Address book could not be created." : "Címjegyzék nem hozható létre.",
+    "Upload new image" : "Új kép feltöltése",
     "The selected image is too big (max 1MB)" : "A kiválasztott kép túl nagy (max. 1 MB)!",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Ez a kártya hibás volt, de ki lett javítva. Kérlek ellenőrizd az adatokat és a véglegesítéshez mentsd el.",
     "No contacts in here" : "Nincsenek névjegyek",
@@ -102,6 +103,9 @@ OC.L10N.register(
     "Colleague" : "Kolléga",
     "Manager" : "Vezető",
     "Assistant" : "Asszisztens",
+    "Agent" : "Ügynök",
+    "Emergency" : "Vészhelyzet",
+    "Co-worker" : "Munkatárs",
     "Gender" : "Nem",
     "Female" : "Nő",
     "Male" : "Férfi",
