@@ -27,12 +27,12 @@ OC.L10N.register(
     "Name" : "Nazwa",
     "Organization" : "Organizacja",
     "Title" : "Tytuł",
-    "Add field …" : "Dodaj pole ...",
+    "Add field …" : "Dodaj pole…",
     "Save changes" : "Zapisz zmiany",
     "Address book" : "Książka adresowa",
-    "Loading contacts …" : "Ładowanie kontaktów ...",
+    "Loading contacts …" : "Ładowanie kontaktów…",
     "Import into" : "Importuj do",
-    "Importing..." : "Importowanie...",
+    "Importing..." : "Importowanie…",
     "Select your addressbook" : "Wybierz książkę adresową",
     "Import is disabled because no writable address book had been found." : "Import wyłączony, ponieważ nie znaleziono książki adresowej do zapisu.",
     "No search result for {query}" : "Brak wyników wyszukiwania dla zapytania {query}",
@@ -62,8 +62,8 @@ OC.L10N.register(
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Wspierane są tylko vCard w wersji 4.0 (RFC6350) lub 3.0 (RFC2426).",
     "Contact could not be moved." : "Nie udało się przenieść kontaktu",
     "Contact could not be saved." : "Nie udało się zapisać kontaktu.",
-    "Waiting for the server to be ready…" : "Czekam, aż serwer będzie gotowy...",
-    "Importing…" : "Importowanie...",
+    "Waiting for the server to be ready…" : "Czekam, aż serwer będzie gotowy…",
+    "Importing…" : "Importowanie…",
     "Display name" : "Wyświetlana nazwa",
     "Nickname" : "Pseudonim",
     "Detailed name" : "Szczegółowa nazwa",
