@@ -20,6 +20,7 @@ OC.L10N.register(
     "Address book name" : "Ime imenika",
     "Only these special characters are allowed: -_.!?#|()" : "Dovoljeni so le sledeči posebni znaki: -_.!?#|()",
     "Address book could not be created." : "Imenika ni mogoče ustvariti.",
+    "Upload new image" : "Naloži novo sliko",
     "The selected image is too big (max 1MB)" : "Izbrana slika je prevelika (omejitev je 1 MB).",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Ta kartica je počkodovana in je bila popravljena. Preveri podatke in shrani, da bodo spremembe trajne.",
     "No contacts in here" : "Ni dodanega nobenega stika!",
@@ -58,7 +59,7 @@ OC.L10N.register(
     "You don't have permission to write to this addressbook." : "Nimate dovoljenja za zapisovanje v imenik",
     "Contact could not be created." : "Stika ni mogoče ustvariti.",
     "No contacts in file. Only vCard files are allowed." : "V datoteki ni stikov. Dovoljene so samo vCard datoteke.",
-    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Podpiramo samo vCard verzije 4.0 (RFC6350) ali verzije 3.0 (RFC2426).",
+    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Podprti sta le različici vCard 4.0 (RFC6350) in vCard 3.0 (RFC2426).",
     "Contact could not be moved." : "Stika ni mogoče premakniti",
     "Contact could not be saved." : "Stikov ne morem shraniti.",
     "Waiting for the server to be ready…" : "Čakanje na strežnik ...",
